@@ -71,6 +71,7 @@ class EnvelopeOptions(NamedTuple):
     expected_optimized_image_filename: Optional[str] = None
     max_overhead: Optional[float] = None
     force_reprocessing: Optional[bool] = None
+    task_thread: Optional[str] = None
 
 
 class ApiRequest(NamedTuple):
@@ -192,7 +193,7 @@ class ToilmoreHTTPRequester(object):
         api_request: ApiRequest,
         use_tag: UseTag,
         attempt_no: int,
-        attempts: int = RETRY_COUNT,
+        attempts: int = RETRY_COUNT
     ) -> StatusAndBody:
         """
         Submits an image for optimization to the light/lux API.
@@ -275,12 +276,17 @@ class ToilmoreHTTPRequester(object):
         file_hash: str,
         attempt_no: int
     ) -> dict:
-
         use_envelope_options = api_request.envelope_options
-        force_reprocessing = (
-            use_envelope_options.force_reprocessing
-            if use_envelope_options else False
-        )
+        if use_envelope_options:
+            force_reprocessing = use_envelope_options.force_reprocessing
+            expected_optimized_image_filename = (
+                use_envelope_options.expected_optimized_image_filename
+            )
+            task_thread = use_envelope_options.task_thread
+        else:
+            force_reprocessing = False
+            expected_optimized_image_filename = None
+            task_thread = file_hash
         adjustments = api_request.adjustments
         original_image_size_in_bytes = api_request.one_pass_info.file_size
 
@@ -288,19 +294,17 @@ class ToilmoreHTTPRequester(object):
             force_reprocessing = False
         if not adjustments:
             adjustments = {}
-
-        expected_optimized_image_filename = (
-            use_envelope_options.expected_optimized_image_filename
-            if use_envelope_options else None
-        )
         if not expected_optimized_image_filename:
             expected_optimized_image_filename = (
                 f"/python-sdk-call/at-hash/optimized/{file_hash}"
             )
+        if not task_thread:
+            task_thread = file_hash
         # Let's use a codified relative path so that we can test-match in tests
         use_relative_path = (
             f"/python-sdk-call/at-hash/input/{file_hash}/attempt_{attempt_no}"
         )
+
         request_json_body = {
             "image_file_hash": file_hash,
             "original_image_size_in_bytes": original_image_size_in_bytes,
@@ -313,7 +317,7 @@ class ToilmoreHTTPRequester(object):
             ],
             "force_reprocessing": force_reprocessing,
             "shimmercat_job_record": {
-                "task_thread": file_hash,
+                "task_thread": task_thread,
             }
         }
         if self._api_endpoint.api_module == constants.LUX_API_KEY:
